seterrorhandler(print);


--Creates our Main Frame.
local frame = CreateFrame("FRAME", nil, UIParent);
frame:RegisterEvent("ADDON_LOADED");
frame:RegisterEvent("PLAYER_ENTERING_WORLD");
frame:RegisterEvent("PLAYER_MONEY");

--Creates Options Frame
local NEGOptions = CreateFrame( "Frame", "NEGOptions", UIParent );

--Creates Goals Frame
local NEGAbout = CreateFrame( "Frame", "NEGAbout", NEGOptions);


--Global Variables.
local SetupHookOnce = false;
local ShowOverdraftWarnOnce = false;
local ActualGold = 0;

local CostEditBox;
local ItemEditBox;





--======================================================================================================
--Main Event Handler.
--======================================================================================================
function frame:OnEvent(event, arg1, arg2)
	
	if event == "ADDON_LOADED" and arg1 == "NestEgg" then
		
		--Create Database
		if NegGoalsDB  == nil then 
			NegGoalsDB = {}			
		end		
		
		--Prints addon loaded message to chat window.
		print("|cffffd700N|cffebd040e|cffd5c881s|cffc0c0c0t|cffc3a292E|cffc78262g|cffc96333g|r loaded.|cff0099ff Type '/neg options' to adjust settings.|r");

		--Setup Commands List
		SLASH_NEG1 = "/neg";
		SLASH_NEG2 = "/NEG";
		SlashCmdList["NEG"] = SlashHandler;
		
		--Check for Percentage if Null then default to 15%
		if (PercentToHide == nil) then
			PercentToHide = 15; 
		end		
		
		--Check for Threshold if Null then default to 0
		if (ThresholdAmount == nil) then
			ThresholdAmount = 0; 
		end		
		
		--Make the alert disabled by default.
		if (OverdraftAlert == nil) then
			OverdraftAlert = 0;
		end
		
		
		--Options.
		SetupOptions();	
		
		--Goals
		SetupAbout();
		
		--Build Goals
		BuildGoals(NGoals, 325, 225, 275, -325);
		
	end
	
	
	if event == "PLAYER_ENTERING_WORLD" then
		--Called once during addon load so money frame is already hooked.
		--Will only be called again during a UiReload / Loading Screen
		if SetupHookOnce == false then
			HookMoney();
			SetupHookOnce = true;
		end	
	end
	
	
	
	if event == "PLAYER_MONEY" then
		--Check to see if the player is going to over draft soon.
		--Warn them if that's the case.
		local Gold = floor(abs(ActualGold / 10000))
		
		if (OverdraftAlert == 1) then
			if (ShowOverdraftWarnOnce == false) then
				if (Gold <= tonumber(ThresholdAmount)) then
					OverdraftWarningMessage();
					ShowOverdraftWarnOnce = true;
				end
			end
		end
		local CurrentGold = floor(abs(GetMoney() / 10000));
		local TestGold = (Gold - CurrentGold);

		CheckGoal(TestGold); --Checks goals against money saved.
	end
	
	
end


--======================================================================================================
--Function that checks list of goals against money saved.
--======================================================================================================
function CheckGoal(gold)
	for k,v in pairs(NegGoalsDB) do
	
		
	
	
		if gold >= tonumber(NegGoalsDB[k]["cost"]) then
			GoalReachedMessage(NegGoalsDB[k]["name"], tonumber(NegGoalsDB[k]["cost"]));			
			RemoveGoal(NegGoalsDB[k]["name"]);			
			break;
		end
	end
end


--======================================================================================================
--Function that hooks into money function.
--======================================================================================================
function HookMoney()

		--Hook the Function that returns how much money the player currently has.
		hooksecurefunc("GetMoney", function(...)
		end)
		
		local OldGetMoney = GetMoney --Preserve the Original Function
		
		GetMoney = function(...)
			ActualGold = OldGetMoney(); --Stored to display via command line.
			local AmountToHide = OldGetMoney() * (PercentToHide / 100); --Calculate the amount of gold that will need to be removed.
			return OldGetMoney() - removeDecimal(AmountToHide);
		end	

end





--======================================================================================================
--Sets up command line settings.
--======================================================================================================
function SlashHandler(msg)
    if msg:upper() == "ACTUAL" then --Toggle Debug Options
		print("You actually have " .. GetCoinTextureString(ActualGold));
	elseif msg:upper() == "HELP" or msg:upper() == "" or msg == nil then --Displays Help
		print("NestEgg: Command List");
		print("----------------------------------------------------------------------");
		print("|cff0099ffOptions|r - Displays the options and goals screen.");
		print("|cff0099ffActual|r - Displays the actual amount of gold you own.");
		print("|cff0099ffAbout|r - Displays the about screen.");
		print("----------------------------------------------------------------------");
	elseif msg:upper() == "ABOUT" then -- Show About Screen
		InterfaceOptionsFrame_OpenToCategory(NEGAbout);
	elseif msg:upper() == "OPTIONS" then -- Show Main Options
		InterfaceOptionsFrame_OpenToCategory(NEGOptions);
	--elseif msg:upper() == "ADD" then -- Testing Options
		--SaveGoal("Test Item", "1");
	--elseif msg:upper() == "REMOVE" then -- Testing Options
		--RemoveGoal("Black JC Mount3");
	else --Unknown Command
		print("|cffff0000Unknown Command|r - Type /neg help for a list of valid commands.");		
    end
end










function SetupOptions()
	--======================================================================================================
	--Create Main Frame
	--======================================================================================================

	NEGOptions:SetScript("OnShow", function(self) setupcheckboxes() end)
	NEGOptions.name = "|cffffd700N|cffebd040e|cffd5c881s|cffc0c0c0t|cffc3a292E|cffc78262g|cffc96333g|r";
	InterfaceOptions_AddCategory(NEGOptions);

	
	
	--======================================================================================================
	--Add Addon Name to Addon List
	--======================================================================================================
	local NEGHeader = NEGOptions:CreateFontString(nil, "ARTWORK")
	NEGHeader:SetFontObject(GameFontNormalLarge)
	NEGHeader:SetJustifyH("LEFT") 
	NEGHeader:SetJustifyV("TOP")
	NEGHeader:ClearAllPoints()
	NEGHeader:SetPoint("TOPLEFT", 16, -16)
	NEGHeader:SetText("|cffffd700N|cfff5d420e|cffebd040s|cffe0cc61t|cffd5c881E|cffcbc4a1g|cffc0c0c0g|cffc1b4ad |cffc3a698v|cffc499841|cffc68b70.|cffc77e5c0|cffc97047.|cffc963334|r")
		
	--======================================================================================================
	--Description of the Addon
	--======================================================================================================	
	local NEGDescription = NEGOptions:CreateFontString(nil, "ARTWORK")
	NEGDescription:SetFontObject(GameFontWhite)
	NEGDescription:SetJustifyH("LEFT") 
	NEGDescription:SetJustifyV("TOP")
	NEGDescription:ClearAllPoints()
	NEGDescription:SetPoint("TOPLEFT", 16, -38)
	NEGDescription:SetText("Hide money and always have some in reserve.")

								
	--======================================================================================================
	--Addon Logo
	--======================================================================================================		
	local NEGLogo = NEGOptions:CreateTexture(nil, "BACKGROUND")
	NEGLogo:SetTexture("Interface\\Addons\\NestEgg\\Images\\Logo")
	NEGLogo:SetPoint("TOPLEFT", 530 , -20)
	NEGLogo:SetWidth(70)
	NEGLogo:SetHeight(70)
		
		
	
	--======================================================================================================
	--Header / Horizontal Bar
	--======================================================================================================	
	local label = NEGOptions:CreateFontString(nil, "BACKGROUND", "GameFontNormal")
	label:SetPoint("TOP")
	label:SetPoint("BOTTOM")
	label:SetJustifyH("CENTER")
	label:SetJustifyV("TOP")
	label:SetPoint("TOP", 0, -100) --Center
	label:SetText("Options")

	local left = NEGOptions:CreateTexture(nil, "BACKGROUND")
	left:SetTexture("Interface\\Tooltips\\UI-Tooltip-Border")
	left:SetPoint("TOPLEFT", 16 , -100)
	left:SetPoint("RIGHT", label, "LEFT", -5, 0)
	left:SetHeight(8)
	left:SetTexCoord(0.81, 0.94, 0.5, 1)		
		
	local right = NEGOptions:CreateTexture(nil, "BACKGROUND")
	right:SetTexture("Interface\\Tooltips\\UI-Tooltip-Border")
	right:SetPoint("TOPRIGHT", -16 , -100)
	right:SetPoint("LEFT", label, "RIGHT", 5, 0)
	right:SetHeight(8)
	right:SetTexCoord(0.81, 0.94, 0.5, 1)
	
	
	--======================================================================================================
	--Information
	--======================================================================================================
	local NEGInformation = NEGOptions:CreateFontString(nil, "ARTWORK")
	NEGInformation:SetFontObject(GameFontNormal)
	NEGInformation:SetJustifyH("LEFT") 
	NEGInformation:SetJustifyV("TOP")
	NEGInformation:ClearAllPoints()
	NEGInformation:SetPoint("TOPLEFT", 16, -120)
	NEGInformation:SetText("|cffffffffBelow you will be allowed to choose a percentage of gold that will be hidden from your view.")

	
	local NEGInformation2 = NEGOptions:CreateFontString(nil, "ARTWORK")
	NEGInformation2:SetFontObject(GameFontNormal)
	NEGInformation2:SetJustifyH("LEFT") 
	NEGInformation2:SetJustifyV("TOP")
	NEGInformation2:ClearAllPoints()
	NEGInformation2:SetPoint("TOPLEFT", 16, -140)
	NEGInformation2:SetText("|cffffffffChoose a percentage between 0 and 99 and it will calculate that percentage of gold to hide.")
	
	
	--======================================================================================================
	--Example
	--======================================================================================================
	local NEGExample = NEGOptions:CreateFontString(nil, "ARTWORK")
	NEGExample:SetFontObject(GameFontNormal)
	NEGExample:SetJustifyH("LEFT") 
	NEGExample:SetJustifyV("TOP")
	NEGExample:ClearAllPoints()
	NEGExample:SetPoint("TOPLEFT", 16, -170)
	NEGExample:SetText("Example: |cffffffffIf you have 100,000g and you set it to 25 then you will only see 75,000g on hand.")



	
	
		
	--======================================================================================================
	--Alert Check Button
	--======================================================================================================
	local NEGCheckButton = CreateFrame("CheckButton", "NEGCheckButton", NEGOptions, "OptionsCheckButtonTemplate");
	NEGCheckButton:SetPoint("TOPLEFT", NEGOptions, "TOPLEFT", 16, -230);
	NEGCheckButton:SetScript("OnClick", function(self) ToggleAlert() end);
	NEGCheckButtonText:SetText("Alert when below threshold amount.");	
	NEGCheckButton:SetChecked(OverdraftAlert);	
		
		
		
	--======================================================================================================
	--Threshold Label
	--======================================================================================================
	local NEGThresholdLabel = NEGOptions:CreateFontString(nil, "ARTWORK");
	NEGThresholdLabel:SetFontObject(GameFontNormal);
	NEGThresholdLabel:SetJustifyH("LEFT"); 
	NEGThresholdLabel:SetJustifyV("TOP");
	NEGThresholdLabel:ClearAllPoints();
	NEGThresholdLabel:SetPoint("TOPLEFT", 16, -270);
	NEGThresholdLabel:SetText("|cffffffffThreshold:");
	

		
	--======================================================================================================
	--Threshold Edit Box
	--======================================================================================================	
	local ThresholdEditBox = CreateFrame("EditBox", "NegThreshBox", NEGOptions, "InputBoxTemplate");
	ThresholdEditBox:SetWidth(80);
	ThresholdEditBox:SetHeight(20);
	ThresholdEditBox:SetJustifyH("LEFT"); 
	ThresholdEditBox:SetJustifyV("TOP");
	ThresholdEditBox:SetPoint("TOPLEFT", 100, -265);
	ThresholdEditBox:SetFontObject("GameFontHighlight");
	ThresholdEditBox:SetMaxLetters(8);
	ThresholdEditBox:SetNumeric(true);
	ThresholdEditBox:SetText(ThresholdAmount); 
	ThresholdEditBox:SetAutoFocus(false);
	ThresholdEditBox:SetCursorPosition(0);
		

	--======================================================================================================
	--Okay Button
	--======================================================================================================	
	local ThresholdOkay = CreateFrame("Button", nil, NEGOptions, "UIPanelButtonTemplate")
	ThresholdOkay:SetWidth(50);
	ThresholdOkay:SetHeight(20);
	ThresholdOkay:SetText("Okay");
	ThresholdOkay:ClearAllPoints();
	ThresholdOkay:SetPoint("CENTER", NEGOptions, "CENTER", -100, 8);
		
	ThresholdOkay:SetScript("OnMouseUp",function(self, button)
		PlaySound("UChatScrollButton");
		self:SetScript("OnUpdate",nil);		
		if button == "LeftButton" then
			ThresholdAmount = ThresholdEditBox:GetText();
		end		
	end)	
	
	
	
	
	
	
	--======================================================================================================
	--Percent Label
	--======================================================================================================
	local NEGLabel = NEGOptions:CreateFontString(nil, "ARTWORK");
	NEGLabel:SetFontObject(GameFontNormal);
	NEGLabel:SetJustifyH("LEFT") ;
	NEGLabel:SetJustifyV("TOP");
	NEGLabel:ClearAllPoints();
	NEGLabel:SetPoint("TOPLEFT", 16, -195);
	NEGLabel:SetText("|cffffffffPercent:");
	
	
	

		
	--======================================================================================================
	--Edit Box
	--======================================================================================================	
	local PercentEditBox = CreateFrame("EditBox", "NegPercentBox", NEGOptions, "InputBoxTemplate");
	PercentEditBox:SetWidth(80);
	PercentEditBox:SetHeight(20);
	PercentEditBox:SetJustifyH("LEFT");
	PercentEditBox:SetJustifyV("TOP");
	PercentEditBox:SetPoint("TOPLEFT", 80, -190);
	PercentEditBox:SetFontObject("GameFontHighlight");
	PercentEditBox:SetMaxLetters(2);
	PercentEditBox:SetNumeric(true);
	PercentEditBox:SetText(PercentToHide); 
	PercentEditBox:SetAutoFocus(false);
	PercentEditBox:SetCursorPosition(0);
		

	--======================================================================================================
	--Okay Button
	--======================================================================================================	
	local PercentOkay = CreateFrame("Button", nil, NEGOptions, "UIPanelButtonTemplate")
	PercentOkay:SetWidth(50);
	PercentOkay:SetHeight(20);
	PercentOkay:SetText("Okay");
	PercentOkay:ClearAllPoints();
	PercentOkay:SetPoint("CENTER", NEGOptions, "CENTER", -120, 83);
	
	
	PercentOkay:SetScript("OnMouseUp",function(self, button)
		PlaySound("UChatScrollButton");
		self:SetScript("OnUpdate",nil);		
		if button == "LeftButton" then
			PercentToHide = PercentEditBox:GetText();
		end		
	end)
		
		
	
		
		

		

	--======================================================================================================
	--Header / Horizontal Bar
	--======================================================================================================	

	local label2 = NEGOptions:CreateFontString(nil, "BACKGROUND", "GameFontNormal")
	label2:SetPoint("TOP")
	label2:SetPoint("BOTTOM")
	label2:SetJustifyH("CENTER")
	label2:SetJustifyV("TOP")
	label2:SetPoint("TOP", 0, -300) --Center
	label2:SetText("Goals")
		
	
	local left2 = NEGOptions:CreateTexture(nil, "BACKGROUND")
	left2:SetTexture("Interface\\Tooltips\\UI-Tooltip-Border")
	left2:SetPoint("TOPLEFT", 16 , -300)
	left2:SetPoint("RIGHT", label2, "LEFT", -5, 0)
	left2:SetHeight(8)
	left2:SetTexCoord(0.81, 0.94, 0.5, 1)		
		
	local right2 = NEGOptions:CreateTexture(nil, "BACKGROUND")
	right2:SetTexture("Interface\\Tooltips\\UI-Tooltip-Border")
	right2:SetPoint("TOPRIGHT", -16 , -300)
	right2:SetPoint("LEFT", label2, "RIGHT", 5, 0)
	right2:SetHeight(8)
	right2:SetTexCoord(0.81, 0.94, 0.5, 1)
	

	
	
	
	
	
	
	
	--======================================================================================================
	--Item Name Label
	--======================================================================================================
	local NEGItemLabel = NEGOptions:CreateFontString(nil, "ARTWORK");
	NEGItemLabel:SetFontObject(GameFontNormal);
	NEGItemLabel:SetJustifyH("LEFT") ;
	NEGItemLabel:SetJustifyV("TOP");
	NEGItemLabel:ClearAllPoints();
	NEGItemLabel:SetPoint("TOPLEFT", 16, -325);
	NEGItemLabel:SetText("|cffffffffItem Name:");
	
	
	

		
	--======================================================================================================
	--Item Edit Box
	--======================================================================================================	
	ItemEditBox = CreateFrame("EditBox", "NegItemBox", NEGOptions, "InputBoxTemplate");
	ItemEditBox:SetWidth(230);
	ItemEditBox:SetHeight(20);
	ItemEditBox:SetJustifyH("LEFT");
	ItemEditBox:SetJustifyV("TOP");
	ItemEditBox:SetPoint("TOPLEFT", 20, -345);
	ItemEditBox:SetFontObject("GameFontHighlight");
	ItemEditBox:SetMaxLetters(50);
	--ItemEditBox:SetNumeric(true);
	ItemEditBox:SetText(""); 
	ItemEditBox:SetAutoFocus(false);
	ItemEditBox:SetCursorPosition(0);
		


	
	--======================================================================================================
	--Cost Name Label
	--======================================================================================================
	local NEGCostLabel = NEGOptions:CreateFontString(nil, "ARTWORK");
	NEGCostLabel:SetFontObject(GameFontNormal);
	NEGCostLabel:SetJustifyH("LEFT") ;
	NEGCostLabel:SetJustifyV("TOP");
	NEGCostLabel:ClearAllPoints();
	NEGCostLabel:SetPoint("TOPLEFT", 16, -385);
	NEGCostLabel:SetText("|cffffffffItem Cost:");
	
	
	

		
	--======================================================================================================
	--Cost Edit Box
	--======================================================================================================	
	CostEditBox = CreateFrame("EditBox", "NegCostBox", NEGOptions, "InputBoxTemplate");
	CostEditBox:SetWidth(230);
	CostEditBox:SetHeight(20);
	CostEditBox:SetJustifyH("LEFT");
	CostEditBox:SetJustifyV("TOP");
	CostEditBox:SetPoint("TOPLEFT", 20, -400);
	CostEditBox:SetFontObject("GameFontHighlight");
	CostEditBox:SetMaxLetters(10);
	CostEditBox:SetNumeric(true);
	CostEditBox:SetText("0"); 
	CostEditBox:SetAutoFocus(false);
	CostEditBox:SetCursorPosition(0);
	
	
	
	--======================================================================================================
	--Add Button
	--======================================================================================================	
	local AddOkay = CreateFrame("Button", nil, NEGOptions, "UIPanelButtonTemplate")
	AddOkay:SetWidth(80);
	AddOkay:SetHeight(20);
	AddOkay:SetText("Add");
	AddOkay:ClearAllPoints();
	AddOkay:SetPoint("TOPLEFT", 80, -450);
	
	
	AddOkay:SetScript("OnMouseUp",function(self, button)
		PlaySound("UChatScrollButton");
		self:SetScript("OnUpdate",nil);		
		if button == "LeftButton" then
		
			if(ItemEditBox:GetText() == "" or ItemEditBox:GetText() == nil) then 
				return;
			end
		
			if(CostEditBox:GetText() == "" or CostEditBox:GetText() == nil) then 
				return;
			end
		
		
			if(DoesGoalExist(ItemEditBox:GetText()) == false) then
				SaveGoal(ItemEditBox:GetText(), CostEditBox:GetText() );
				ItemEditBox:SetText("");
				CostEditBox:SetText("");
			end
		end		
	end)
	
	
	
	
	--======================================================================================================
	--Remove Button
	--======================================================================================================	
	local RemoveOkay = CreateFrame("Button", nil, NEGOptions, "UIPanelButtonTemplate")
	RemoveOkay:SetWidth(80);
	RemoveOkay:SetHeight(20);
	RemoveOkay:SetText("Remove");
	RemoveOkay:ClearAllPoints();
	RemoveOkay:SetPoint("TOPLEFT", 170, -450);
	
	
	RemoveOkay:SetScript("OnMouseUp",function(self, button)
		PlaySound("UChatScrollButton");
		self:SetScript("OnUpdate",nil);		
		if button == "LeftButton" then
			RemoveGoal(ItemEditBox:GetText() );
			ItemEditBox:SetText("");
			CostEditBox:SetText("");
		end		
	end)
	

end




function SetupAbout()

	NEGAbout.name = "About";
	NEGAbout.parent = NEGOptions.name;
	InterfaceOptions_AddCategory(NEGAbout);	
	
	--======================================================================================================
	--Add Addon Name to Addon List
	--======================================================================================================
	local NEGHeader = NEGAbout:CreateFontString(nil, "ARTWORK")
	NEGHeader:SetFontObject(GameFontNormalLarge)
	NEGHeader:SetJustifyH("LEFT") 
	NEGHeader:SetJustifyV("TOP")
	NEGHeader:ClearAllPoints()
	NEGHeader:SetPoint("TOPLEFT", 16, -16)
	NEGHeader:SetText("|cffffd700N|cfff5d420e|cffebd040s|cffe0cc61t|cffd5c881E|cffcbc4a1g|cffc0c0c0g|cffc1b4ad |cffc3a698v|cffc499841|cffc68b70.|cffc77e5c0|cffc97047.|cffc963335|r")
		
	--======================================================================================================
	--Description of the Addon
	--======================================================================================================	
	local NEGDescription = NEGAbout:CreateFontString(nil, "ARTWORK")
	NEGDescription:SetFontObject(GameFontWhite)
	NEGDescription:SetJustifyH("LEFT") 
	NEGDescription:SetJustifyV("TOP")
	NEGDescription:ClearAllPoints()
	NEGDescription:SetPoint("TOPLEFT", 16, -38)
	NEGDescription:SetText("Hide money and always have some in reserve.")

								
	--======================================================================================================
	--Addon Logo
	--======================================================================================================		
	local NEGLogo = NEGAbout:CreateTexture(nil, "BACKGROUND")
	NEGLogo:SetTexture("Interface\\Addons\\NestEgg\\Images\\Logo")
	NEGLogo:SetPoint("TOPLEFT", 530 , -20)
	NEGLogo:SetWidth(70)
	NEGLogo:SetHeight(70)
		
		
	
	--======================================================================================================
	--Header / Horizontal Bar
	--======================================================================================================	
	local label = NEGAbout:CreateFontString(nil, "BACKGROUND", "GameFontNormal")
	label:SetPoint("TOP")
	label:SetPoint("BOTTOM")
	label:SetJustifyH("CENTER")
	label:SetJustifyV("TOP")
	label:SetPoint("TOP", 0, -100) --Center
	label:SetText("About")

	local left = NEGAbout:CreateTexture(nil, "BACKGROUND")
	left:SetTexture("Interface\\Tooltips\\UI-Tooltip-Border")
	left:SetPoint("TOPLEFT", 16 , -100)
	left:SetPoint("RIGHT", label, "LEFT", -5, 0)
	left:SetHeight(8)
	left:SetTexCoord(0.81, 0.94, 0.5, 1)		
		
	local right = NEGAbout:CreateTexture(nil, "BACKGROUND")
	right:SetTexture("Interface\\Tooltips\\UI-Tooltip-Border")
	right:SetPoint("TOPRIGHT", -16 , -100)
	right:SetPoint("LEFT", label, "RIGHT", 5, 0)
	right:SetHeight(8)
	right:SetTexCoord(0.81, 0.94, 0.5, 1)
	

	--======================================================================================================
	--About
	--======================================================================================================
	
	--Version
	local NEGVersion = NEGAbout:CreateFontString(nil, "ARTWORK")
	NEGVersion:SetFontObject(GameFontNormal)
	NEGVersion:SetJustifyH("LEFT") 
	NEGVersion:SetJustifyV("TOP")
	NEGVersion:ClearAllPoints()
	NEGVersion:SetPoint("TOPLEFT", 16, -120)
	NEGVersion:SetText("Version: |cffffffff1.0.5")
	
	
	--Author
	local NEGAuthor = NEGAbout:CreateFontString(nil, "ARTWORK")
	NEGAuthor:SetFontObject(GameFontNormal)
	NEGAuthor:SetJustifyH("LEFT") 
	NEGAuthor:SetJustifyV("TOP")
	NEGAuthor:ClearAllPoints()
	NEGAuthor:SetPoint("TOPLEFT", 16, -140)
	NEGAuthor:SetText("Author: |cffffffffKillnaction @ Thunderlord")
	
	
	--Category
	local NEGCategory = NEGAbout:CreateFontString(nil, "ARTWORK")
	NEGCategory:SetFontObject(GameFontNormal)
	NEGCategory:SetJustifyH("LEFT") 
	NEGCategory:SetJustifyV("TOP")
	NEGCategory:ClearAllPoints()
	NEGCategory:SetPoint("TOPLEFT", 16, -160)
	NEGCategory:SetText("Category: |cffffffffMiscellaneous")
	
	--Email
	local NEGEmail = NEGAbout:CreateFontString(nil, "ARTWORK")
	NEGEmail:SetFontObject(GameFontNormal)
	NEGEmail:SetJustifyH("LEFT") 
	NEGEmail:SetJustifyV("TOP")
	NEGEmail:ClearAllPoints()
	NEGEmail:SetPoint("TOPLEFT", 16, -180)
	NEGEmail:SetText("Email: |cffffffffKilldnaction@Gmail.com")

	--Website
	local NEGWebsite = NEGAbout:CreateFontString(nil, "ARTWORK")
	NEGWebsite:SetFontObject(GameFontNormal)
	NEGWebsite:SetJustifyH("LEFT") 
	NEGWebsite:SetJustifyV("TOP")
	NEGWebsite:ClearAllPoints()
	NEGWebsite:SetPoint("TOPLEFT", 16, -200)
	NEGWebsite:SetText("Website: |cffffffffHttp://www.curse.com/addons/wow/nestegg")
	
	--Translators
	local NEGTranslators= NEGAbout:CreateFontString(nil, "ARTWORK")
	NEGTranslators:SetFontObject(GameFontNormal)
	NEGTranslators:SetJustifyH("LEFT") 
	NEGTranslators:SetJustifyV("TOP")
	NEGTranslators:ClearAllPoints()
	NEGTranslators:SetPoint("TOPLEFT", 16, -220)
	NEGTranslators:SetText("Translators: |cffffffffNone")

	--Localizations
	local NEGLocalizations= NEGAbout:CreateFontString(nil, "ARTWORK")
	NEGLocalizations:SetFontObject(GameFontNormal)
	NEGLocalizations:SetJustifyH("LEFT") 
	NEGLocalizations:SetJustifyV("TOP")
	NEGLocalizations:ClearAllPoints()
	NEGLocalizations:SetPoint("TOPLEFT", 16, -240)
	NEGLocalizations:SetText("Localizations: |cffffffffEn-US")
	
	--License
	local NEGLicense= NEGAbout:CreateFontString(nil, "ARTWORK")
	NEGLicense:SetFontObject(GameFontNormal)
	NEGLicense:SetJustifyH("LEFT") 
	NEGLicense:SetJustifyV("TOP")
	NEGLicense:ClearAllPoints()
	NEGLicense:SetPoint("TOPLEFT", 16, -260)
	NEGLicense:SetText("License: |cffffffffAll Rights Reserved")

	
	--Credits
	local NEGCredits= NEGAbout:CreateFontString(nil, "ARTWORK")
	NEGCredits:SetFontObject(GameFontNormal)
	NEGCredits:SetJustifyH("LEFT") 
	NEGCredits:SetJustifyV("TOP")
	NEGCredits:ClearAllPoints()
	NEGCredits:SetPoint("TOPLEFT", 16, -280)
	NEGCredits:SetText("Credits: |cffffffffTBD")

	
	--PlaceHolder
	--local NEGPlaceHolder= NEGAbout:CreateFontString(nil, "ARTWORK")
	--NEGPlaceHolder:SetFontObject(GameFontNormal)
	--NEGPlaceHolder:SetJustifyH("LEFT") 
	--NEGPlaceHolder:SetJustifyV("TOP")
	--NEGPlaceHolder:ClearAllPoints()
	--NEGPlaceHolder:SetPoint("TOPLEFT", 16, -520)
	--NEGPlaceHolder:SetText("PlaceHolder: |cffffffff")
	
	
	
	

end



--======================================================================================================
--Saves a Goal to the Database.
--======================================================================================================
function SaveGoal(GoalName, GoalAmount)
	items = {["name"]= GoalName, ["cost"]= GoalAmount}
	table.insert(NegGoalsDB, items);
end


--======================================================================================================
--Removes a Goal from the Database.
--======================================================================================================
function RemoveGoal(itemToRemove)
	for k,v in pairs(NegGoalsDB) do
		if NegGoalsDB[k]["name"] == itemToRemove then
			table.remove (NegGoalsDB, k);
			break;
		end
	end
end


--======================================================================================================
--Returns the cost of a goal.
--======================================================================================================
function GetGoalCost(itemToFind)
	for k,v in pairs(NegGoalsDB) do
		if NegGoalsDB[k]["name"] == itemToFind then
			return NegGoalsDB[k]["cost"];
		end
	end
end


--======================================================================================================
--Checks to see if goal already exists.
--======================================================================================================
function DoesGoalExist(itemToFind)
	for k,v in pairs(NegGoalsDB) do
		if NegGoalsDB[k]["name"] == itemToFind then
			return true;
		end
	end
	return false;
end


--======================================================================================================
--Looks for goal and fills edit boxes with data.
--======================================================================================================
function FillGoals(itemToFind)
	for k,v in pairs(NegGoalsDB) do
		if NegGoalsDB[k]["name"] == itemToFind then
			--return NegGoalsDB[k]["cost"];
			ItemEditBox:SetText(itemToFind);
			CostEditBox:SetText(tonumber(NegGoalsDB[k]["cost"]));
		end
	end
end







function BuildGoals(Name, Width, Height, X, Y)
		
		local BUTTON_HEIGHT = 16 

		
        local Frame = CreateFrame("Frame", Name, NEGOptions)
			Frame:EnableMouse(true)
			Frame:SetSize(Width, Height)
			Frame:SetPoint("TOPLEFT", X , Y)
			Frame.ButtonCount = math.floor((Height-32) / BUTTON_HEIGHT)
			
			Frame:SetBackdrop({
					bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background", tile = true, tileSize = 16,
					edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border", edgeSize = 16,
					insets = { left = 4, right = 4, top = 4, bottom = 4 },
				})
 
					function Frame:Update()
                        local maxValue = #NegGoalsDB

                        FauxScrollFrame_Update(self.ScrollBar, maxValue, self.ButtonCount, BUTTON_HEIGHT)
                        local offset = FauxScrollFrame_GetOffset(self.ScrollBar)
                        for Button = 1, self.ButtonCount do
                                local value = Button + offset
                                if value <= maxValue then
                                        local Button = self.Buttons[Button];
										
                                        Button:SetText(NegGoalsDB[value]["name"]) --Text for the list item.
                                        Button:Show()
                                else
                                        self.Buttons[Button]:Hide()
                                end
                        end
					end

					
					
					Frame:SetScript("OnUpdate", function() -- Auto updates list 
                        Frame:Update()
					end)					
					
					
			   
					local ScrollBar = CreateFrame("ScrollFrame", "$parent_ScrollBar", Frame, "FauxScrollFrameTemplate")
					ScrollBar:SetPoint("TOPLEFT", 0, -8) -- -24
					ScrollBar:SetPoint("BOTTOMRIGHT", -30, 8)				

					
			   
					ScrollBar:SetScript("OnVerticalScroll", function(self, offset)
                        self.offset = math.floor(offset / BUTTON_HEIGHT + 0.5)
                        Frame:Update()
					end)
 
					ScrollBar:SetScript("OnShow", function()
                        Frame:Update()
					end)
							
 
					Frame.ScrollBar = ScrollBar		

					local Buttons = setmetatable({}, { __index = function(t, i)
                        local Button = CreateFrame("Button", "$parent_Button" .. i, Frame)
                        Button:SetSize(Width-55, BUTTON_HEIGHT)
                        Button:SetNormalFontObject(GameFontHighlightLeft)
                        if i == 1 then
                                Button:SetPoint("TOPLEFT", ScrollBar, 8, 0)
                        else
                                Button:SetPoint("TOPLEFT", Frame.Buttons[i-1], "BOTTOMLEFT")
                        end
						
						
						Button:SetScript("OnMouseUp",function(self, button) self:SetScript("OnUpdate",nil)
							if button == "LeftButton" then
								Frame:Update()
								PlaySound("UChatScrollButton");
								--print(GetGoalCost(Button:GetText()));
								FillGoals(Button:GetText());
							end
						end)
						
                        rawset(t, i, Button)
                        return Button
					end })
 
                Frame.Buttons = Buttons
                Frame:Update()


end









--======================================================================================================
--Toggle Overdraft alert.
--======================================================================================================
function ToggleAlert()
	if OverdraftAlert == 1 then
		OverdraftAlert = 0;
	else
		OverdraftAlert = 1;
	end
end



--======================================================================================================
--Overdraft Alert Message.
--======================================================================================================
function OverdraftWarningMessage()

		local Warn = CreateFrame("Frame", nil, UIParent)
		Warn:SetMovable(true)
		Warn:EnableMouse(true)
		Warn:RegisterForDrag("LeftButton")
	
		Warn:SetBackdrop({
						bgFile = [[Interface\Tooltips\UI-Tooltip-Background]],
						edgeFile = [[Interface\DialogFrame\UI-DialogBox-Border]],
						tile = true, tileSize = 16, edgeSize = 32,
						insets = { left = 3, right = 3, top = 5, bottom = 3 }
					})
		Warn:SetBackdropColor(0, 0, 0, 1)
		Warn:SetWidth(300)
		Warn:SetHeight(200)
		Warn:SetPoint("CENTER", UIParent, "CENTER")
		Warn:SetFrameStrata("DIALOG")
		
		
		local WarnMessage = Warn:CreateFontString(nil, "ARTWORK")
		WarnMessage:SetFontObject(GameFontNormal)
		WarnMessage:SetJustifyH("LEFT") 
		WarnMessage:SetJustifyV("TOP")
		WarnMessage:SetWidth(200)
		WarnMessage:SetHeight(150)
		WarnMessage:ClearAllPoints()
		WarnMessage:SetPoint("CENTER", 0, -10)
		WarnMessage:SetText("NestEgg has determined that your actual on hand money has dropped below the threshold you have supplied, if you continue to spend you may run out of money.")
		
		
		
		local okay = CreateFrame("Button", nil, Warn, "UIPanelButtonTemplate")
		okay:SetHeight(20)
		okay:SetWidth(100)
		okay:SetText("Okay")
		okay:ClearAllPoints()
		okay:SetPoint("CENTER", 0, -50)
		
		okay:SetScript("OnMouseUp",function(self, button)
			PlaySound("UChatScrollButton");
			self:SetScript("OnUpdate",nil)		
			if button == "LeftButton" then
				Warn:Hide();
			end		
		end)
		


end



--======================================================================================================
--Goal Reached Alert Message.
--======================================================================================================
function GoalReachedMessage(goal, gold)

		for variable = 0, 100 do
			--print ( variable )
			if variable == 1 then
				PlaySound("LevelUp");
			end
			
			if variable == 100 then
				PlaySound("QUESTCOMPLETED");
			end
		end
		
		
		

		local Alert = CreateFrame("Frame", nil, UIParent)
		Alert:SetMovable(true)
		Alert:EnableMouse(true)
		Alert:RegisterForDrag("LeftButton")
	
		Alert:SetBackdrop({
						bgFile = [[Interface\Tooltips\UI-Tooltip-Background]],
						edgeFile = [[Interface\DialogFrame\UI-DialogBox-Border]],
						tile = true, tileSize = 16, edgeSize = 32,
						insets = { left = 3, right = 3, top = 5, bottom = 3 }
					})
		Alert:SetBackdropColor(0, 0, 0, 1)
		Alert:SetWidth(300)
		Alert:SetHeight(200)
		Alert:SetPoint("CENTER", UIParent, "CENTER")
		Alert:SetFrameStrata("DIALOG")
		
		
		local AlertMessage = Alert:CreateFontString(nil, "ARTWORK")
		AlertMessage:SetFontObject(GameFontNormal)
		AlertMessage:SetJustifyH("LEFT") 
		AlertMessage:SetJustifyV("TOP")
		AlertMessage:SetWidth(200)
		AlertMessage:SetHeight(150)
		AlertMessage:ClearAllPoints()
		AlertMessage:SetPoint("CENTER", 0, -10)
		AlertMessage:SetText("Congratulations you have successfully reached your goal of " .. gold .. " gold and you can now acquire a " .. goal .. ".")
		
		
		
		local okay = CreateFrame("Button", nil, Alert, "UIPanelButtonTemplate")
		okay:SetHeight(20)
		okay:SetWidth(100)
		okay:SetText("Okay")
		okay:ClearAllPoints()
		okay:SetPoint("CENTER", 0, -50)
		
		okay:SetScript("OnMouseUp",function(self, button)
			PlaySound("UChatScrollButton");
			self:SetScript("OnUpdate",nil)		
			if button == "LeftButton" then
				Alert:Hide();
			end		
		end)
		


end














--======================================================================================================
--Loads the saved variable for the check box. 
--======================================================================================================
function setupcheckboxes()
	NEGCheckButton:SetChecked(OverdraftAlert);
end


--======================================================================================================
--Removes any decimals from our rounded Money Value after we remove a percentage of it. 
--======================================================================================================
function removeDecimal(num)
	local floor = math.floor(num)
	local ceiling = math.ceil(num)
	
	if (num - floor) >= 0.5 then
		return ceiling
	end
	
	return floor
end


--======================================================================================================
--Splits a string based on a delimiter.
--======================================================================================================
function split(inputstr, sep)
        if sep == nil then
                sep = "%s"
        end
        t={} ; i=1
        for str in string.gmatch(inputstr, "([^"..sep.."]+)") do
                t[i] = str
                i = i + 1
        end
        return t
end





frame:SetScript("OnEvent", frame.OnEvent);